Skip to contents

Processes and validates market price data, filtering for reasonable price ranges and calculating median prices by species group and family.

Usage

validate_prices(preprocessed_data)

Arguments

preprocessed_data

Preprocessed survey data containing market information

Value

A dataframe with validated market prices