Ingest WF Catch Survey Data
ingest_wf_surveys.RdRetrieves WF catch survey data (v1 and v2) from Kobotoolbox, processes it, and uploads the raw data as Parquet files to cloud storage.
Usage
ingest_wf_surveys(log_threshold = logger::DEBUG)ingest_wf_surveys.RdRetrieves WF catch survey data (v1 and v2) from Kobotoolbox, processes it, and uploads the raw data as Parquet files to cloud storage.
ingest_wf_surveys(log_threshold = logger::DEBUG)